@@ -2,8 +2,11 @@
    .prepare.con(x,implement="ENVI",...)
 }
 'create_gdal' <- function(x,...) {
-   requireNamespace("rgdal",quietly=.isPackageInUse())
-   .prepare.con(x,implement="GDAL",...)
+   if (!.isPackageInUse()) {
+      .rgdal_requireNamespace()
+      return(.prepare.con(x,implement="RGDAL",...))
+   }
+   .prepare.con(x,implement="EGDAL",...)
 }
 #'create_ncdf' <- function(x,...) {
 #   requireNamespace("ncdf4",quietly=.isPackageInUse())
